@@ -30,24 +30,24 @@
 #define SHAKING_BARRIER 17
 #define kAccFilter 0.1
 #define EPS 0.000000000001
+#define INTERVAL 20
 
 // Constructor
 Accelerometer::Accelerometer(QWidget *parent, ErrorHandler *errorHandler)
     : QWidget(parent)
 {
     eh = errorHandler;
-    orientation = new devOrientation(errorHandler);
+    orientation = new devOrientation();
     vx = 0.0f;
     vy = 0.0f;
     offsetX = 0.0f;
     offsetY = 0.0f ;
     activated = true;
-    blurTimer = new QTimer;
-    blurTimer->setSingleShot(true);
+
+    prevAcc = QVector2D(0, 0);
 
     connect(orientation,SIGNAL(dataProcessed(QVector3D)),
             this,SLOT(setOrientation(QVector3D)));
-    connect(blurTimer, SIGNAL(timeout()), SLOT(applyBlur()));
 }
 
 Accelerometer::~Accelerometer()
@@ -61,7 +61,6 @@ void Accelerometer::applyBlur() {
 // Processes values of accelertion and counts offset of Brush
 // Also it handles shaking of tablet
 void Accelerometer::setOrientation(QVector3D accVector3) {
-
     // Checks device shaking (clearing workspace)
     if(fabs(accVector3.y()) > SHAKING_BARRIER)
         emit accShaking();
@@ -82,8 +81,10 @@ void Accelerometer::setOrientation(QVector3D accVector3) {
         accVector3.setY(G*sin(roll));
 
         // high-pass filter
-        accVector3.setX(accVector3.x()*kAccFilter + (1.0 - kAccFilter)*accVector3.x());
-        accVector3.setY(accVector3.y()*kAccFilter + (1.0 - kAccFilter)*accVector3.y());
+        accVector3.setX(accVector3.x()*kAccFilter + (1.0 - kAccFilter)*prevAcc.x());
+        accVector3.setY(accVector3.y()*kAccFilter + (1.0 - kAccFilter)*prevAcc.y());
+
+        prevAcc = QVector2D(accVector3.x(), accVector3.y());
 
         // Counting offset of Brush
         offsetX = vx + (accVector3.x())*dT*dT/2;
@@ -92,9 +93,6 @@ void Accelerometer::setOrientation(QVector3D accVector3) {
         vx = vx + accVector3.x()*dT;
         vy = vy + accVector3.y()*dT;
 
-        accVector3.setX(offsetX/5);
-        accVector3.setY(offsetY/5);
-
         if(fabs(vx) < EPS)
             vx = 0;
 
@@ -118,10 +116,10 @@ void Accelerometer::setActivated(bool activate) {
 
 // Disables accelerometer
 bool Accelerometer::disableAccelerometer(bool disable) {
-    /*if(disable)
-        return orientation->stopTimer(true);
+    if(disable)
+        orientation->killTimer(orientation->timerID);
     else
-        return orientation->stopTimer(false);*/
+        orientation->timerID = orientation->startTimer(INTERVAL);
     return true;
 }
 
