@@ -33,7 +33,7 @@
 #include <QtDBus>
 #include <math.h>
 
-#define INTERVAL 10
+#define INTERVAL 20
 #define MCE_SERVICE "com.nokia.mce"
 #define MCE_REQUEST_PATH "/com/nokia/mce/request"
 #define MCE_REQUEST_IF "com.nokia.mce.request"
@@ -44,7 +44,7 @@ devOrientation::devOrientation(ErrorHandler *errorHandler)
 {
     eh = new ErrorHandler;
     eh = errorHandler;
-    startTimer(INTERVAL);
+    timerID = startTimer(INTERVAL);
 }
 
 void devOrientation::timerEvent(QTimerEvent *) {
@@ -55,7 +55,6 @@ void devOrientation::timerEvent(QTimerEvent *) {
 
     bool sent = QDBusConnection::systemBus().callWithCallback(msg, this,
                                                               SLOT(mceOrientationSlot(QString, QString, QString, int, int, int)));
-
 }
 
 void devOrientation::mceOrientationSlot(const QString &rotation, const QString &stand, const QString &face, int x, int y, int z) {
@@ -65,3 +64,9 @@ void devOrientation::mceOrientationSlot(const QString &rotation, const QString &
 
   emit dataProcessed(QVector3D(-fx, -fy ,-fz));
 }
+
+void devOrientation::stopTimer() {
+    killTimer(timerID);
+}
+
+
