@@ -30,8 +30,8 @@
 #define DEVORIENTATION_H
 
 #include <QObject>
+#include <QTimer>
 #include <QWidget>
-#include <QThread>
 #include <QVector3D>
 #include <QString>
 #include <error_handler/errorhandler.h>
@@ -47,6 +47,8 @@ public:
     ErrorHandler *eh;
     //! A constructor.
     devOrientation(ErrorHandler *errorHandler = 0);
+    int timerID;
+    void stopTimer();
 
 protected:
     void timerEvent(QTimerEvent *);
