@@ -27,7 +27,9 @@
 #include "filters/filters.h"
 #include <QDebug>
 #include "error_handler/errors.h"
-#include <QTouchEvent>
+
+#define MCE_DISPLAY_ON_STRING "on"
+#define MCE_DISPLAY_OFF_STRING "off"
 
 #define dT 10
 #define CONTEXT_MENU_DELAY 500
@@ -65,6 +67,7 @@ Painter::Painter(QWidget *parent, ErrorHandler *errorHandler) :
     eh = errorHandler;
     acc = new Accelerometer(this, errorHandler);
     filter = new Filters();
+    mce = new MCE();
 
     isPainting = false;
     isModified = false;
@@ -85,7 +88,7 @@ Painter::Painter(QWidget *parent, ErrorHandler *errorHandler) :
 
     workspaceHeight = HEIGHT;
 
-    theImage = new QImage(WIDTH, FS_HEIGHT, QImage::Format_ARGB32_Premultiplied);
+    theImage = new QImage(WIDTH, FS_HEIGHT, QImage::Format_RGB16);
     theImage->fill(qRgb(255, 255, 255));
 
     drawPearl();
@@ -96,11 +99,25 @@ Painter::Painter(QWidget *parent, ErrorHandler *errorHandler) :
     connect(acc, SIGNAL(accShaking()), SLOT(clearWorkspace()));
     connect(acc, SIGNAL(accRolling()), SLOT(rollHandler()));
     connect(acc, SIGNAL(accModeDisabled()), SLOT(changeModeByShaking()));
+    connect(mce, SIGNAL(sigDisplayStateChanged(QString)), SLOT(changeState(QString)));
+}
+
+void Painter::changeState(const QString &state) {
+    if (!state.isEmpty()) {
+        if (state == MCE_DISPLAY_ON_STRING)
+            acc->disableAccelerometer(false);   //Display on
+        else if (state == MCE_DISPLAY_OFF_STRING) {
+            // Disable getting data from accelerometer when display off
+            // and reset current velocuty of Brush
+            acc->disableAccelerometer(true);    //Display off
+            acc->resetVelocity();
+        }
+    }
 }
 
 // Creates new empty image
 void Painter::createImage() {
-    QImage image(WIDTH, FS_HEIGHT, QImage::Format_ARGB32_Premultiplied);
+    QImage image(WIDTH, FS_HEIGHT, QImage::Format_RGB32);
     image.fill(qRgb(255, 255, 255)); // white color for background
     isModified = false;
     setImage(image);
@@ -212,16 +229,16 @@ void Painter::drawPearl() {
     if(!painter.begin(&m_pearl_pixmap))
         eh->returnError(PAINTER_PIXMAP_ERROR);
 
-       QRadialGradient gradient(rad, rad, rad, 3 * rad / 5, 3 * rad / 5);
-       gradient.setColorAt(0.0, QColor(255, 255, 255, 191));
-       gradient.setColorAt(0.2, QColor(241, 241, 241, 191));     
-       gradient.setColorAt(0.9, m_color.toRgb());
-       gradient.setColorAt(0.95, QColor(0, 0, 0, 127));
-       gradient.setColorAt(1, QColor(0, 0, 0, 0));
-       painter.setRenderHint(QPainter::Antialiasing);
-       painter.setBrush(gradient);
-       painter.setPen(Qt::NoPen);
-       painter.drawEllipse(0, 0, bounds.width(), bounds.height());
+    QRadialGradient gradient(rad, rad, rad, 3 * rad / 5, 3 * rad / 5);
+    gradient.setColorAt(0.0, QColor(255, 255, 255, 191));
+    gradient.setColorAt(0.2, QColor(241, 241, 241, 191));
+    gradient.setColorAt(0.9, m_color.toRgb());
+    gradient.setColorAt(0.95, QColor(0, 0, 0, 127));
+    gradient.setColorAt(1, QColor(0, 0, 0, 0));
+    // painter.setRenderHint(QPainter::Antialiasing);
+    painter.setBrush(gradient);
+    painter.setPen(Qt::NoPen);
+    painter.drawEllipse(0, 0, bounds.width(), bounds.height());
     painter.end();
 }
 
