@@ -143,7 +143,7 @@ void MainWindow::showAbout() {
                 "<strong>License: GPLv2</strong><br>"
                 "<strong>Page:</strong> liquid-graphic.garage.maemo.org"
                 "<p>The <strong>%2</strong> is a graphic editor for Nokia's tablet. <br>"
-                "In our application user can controll a <br>"
+                "In our application user can control a <br>"
                 "Brush, using accelerometer or touchscreen of a tablet. <br>"
                 "<strong>Developers: </strong>"
                 "<table cellpadding=1 cellspacing=1>"
@@ -216,6 +216,7 @@ bool MainWindow::showExitDialog() {
             if(!saveAs())
                 return false;
             return true;            
+
         case QMessageBox::Discard:
             return true;
             break;
